@@ -1,6 +1,6 @@
 package Statocles::App;
 # ABSTRACT: Base role for Statocles applications
-$Statocles::App::VERSION = '0.045';
+$Statocles::App::VERSION = '0.046';
 use Statocles::Base 'Role';
 use Statocles::Link;
 requires 'pages';
@@ -43,7 +43,7 @@ around pages => sub {
 
 sub url {
     my ( $self, $url ) = @_;
-    $url =~ s{/index[.]html$}{};
+    $url =~ s{/index[.]html$}{/};
     return join "/", $self->url_root, $url;
 }
 
@@ -69,7 +69,7 @@ Statocles::App - Base role for Statocles applications
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
