@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.045';
+$Statocles::App::Blog::VERSION = '0.046';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -19,6 +19,13 @@ has store => (
 );
 
 
+has tag_text => (
+    is => 'ro',
+    isa => HashRef,
+    default => sub { {} },
+);
+
+
 has page_size => (
     is => 'ro',
     isa => Int,
@@ -165,13 +172,31 @@ sub post_files {
 
     my $iter = $self->store->find_files;
     while ( my $path = $iter->() ) {
+        # Files must be in folders
         next unless $path =~ m{^/(\d{4})/(\d{2})/(\d{2})/[^/]+/};
-        next if $path =~ /[.]markdown$/;
 
-        push @pages, Statocles::Page::File->new(
-            path => $path,
-            fh => $self->store->open_file( $path ),
-        );
+        # index.markdown is the post itself
+        next if $path =~ m{/index[.]markdown$};
+
+        if ( $path =~ /[.]markdown/ ) {
+            my $page_path = $path;
+            $page_path =~ s{[.]\w+$}{.html};
+
+            my %args = (
+                path => $page_path,
+                app => $self,
+                layout => $self->site->theme->template( site => 'layout.html' ),
+                document => $self->store->read_document( $path ),
+            );
+
+            push @pages, Statocles::Page::Document->new( %args );
+        }
+        else {
+            push @pages, Statocles::Page::File->new(
+                path => $path,
+                file_path => $self->store->path->child( $path ),
+            );
+        }
     }
 
     return @pages;
@@ -211,7 +236,7 @@ sub _make_post_page {
     for my $tag ( @{ $doc->tags } ) {
         push @tags, $self->link(
             text => $tag,
-            href => join( "/", 'tag', $self->_tag_url( $tag ) ),
+            href => join( "/", 'tag', $self->_tag_url( $tag ), '' ),
         );
     }
 
@@ -314,6 +339,9 @@ sub tag_pages {
             app => $self,
             template => $self->site->theme->template( blog => 'index.html' ),
             layout => $self->site->theme->template( site => 'layout.html' ),
+            data => {
+                tag_text => $self->tag_text->{ $tag },
+            },
         );
 
         my $index = $tag_pages[0];
@@ -363,7 +391,7 @@ sub pages {
 sub tags {
     my ( $self ) = @_;
     my %tagged_docs = $self->_tag_docs( @{ $self->_post_pages } );
-    return map {; $self->link( text => $_, href => join( "/", 'tag', $self->_tag_url( $_ ) ) ) }
+    return map {; $self->link( text => $_, href => join( "/", 'tag', $self->_tag_url( $_ ), '' ) ) }
         sort keys %tagged_docs
 }
 
@@ -416,7 +444,7 @@ sub recent_posts {
 sub page_url {
     my ( $self, $page ) = @_;
     my $url = "".$page->path;
-    $url =~ s{/index[.]html$}{};
+    $url =~ s{/index[.]html$}{/};
     return $url;
 }
 
@@ -432,7 +460,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
@@ -479,6 +507,10 @@ C<deploy> in a nightly cron job.
 
 The L<store|Statocles::Store> to read for documents.
 
+=head2 tag_text
+
+A hash of tag and descriptions to introduce tags. Having a description is optional.
+
 =head2 page_size
 
 The number of posts to put in a page (the main page and the tag pages). Defaults
