@@ -1,6 +1,6 @@
 package Statocles::App::Perldoc;
 # ABSTRACT: Render documentation for Perl modules
-$Statocles::App::Perldoc::VERSION = '0.045';
+$Statocles::App::Perldoc::VERSION = '0.046';
 use Statocles::Base 'Class';
 use Statocles::Page::Plain;
 use Scalar::Util qw( blessed );
@@ -117,38 +117,56 @@ sub pages {
             }
         }
 
+        my $source_path = "$module.src.html";
+        $source_path =~ s{::}{/}g;
+
+        my ( @parts ) = split m{::}, $module;
+        my @crumbtrail;
+        for my $i ( 0..$#parts ) {
+            my $trail_module = join "::", @parts[0..$i];
+            if ( $modules{ $trail_module } ) {
+                push @crumbtrail, {
+                    text => $parts[ $i ],
+                    href => $self->url( $self->_module_href( $trail_module ) ),
+                };
+            }
+            else {
+                push @crumbtrail, {
+                    text => $parts[ $i ],
+                };
+            }
+        }
+
+        my %page_args = (
+            layout => $self->site->theme->template( site => 'layout.html' ),
+            template => $self->site->theme->template( perldoc => 'pod.html' ),
+            content => "$dom",
+            app => $self,
+            path => $self->_module_href( $module ),
+            data => {
+                source_path => $self->url( $source_path ),
+                crumbtrail => \@crumbtrail,
+            },
+        );
+
         if ( $module eq $self->index_module ) {
-            unshift @pages, Statocles::Page::Plain->new(
-                path => join( '/', 'index.html' ),
-                layout => $self->site->theme->template( site => 'layout.html' ),
-                template => $self->site->theme->template( perldoc => 'pod.html' ),
-                content => "$dom",
-                app => $self,
-            );
+            unshift @pages, Statocles::Page::Plain->new( %page_args );
         }
         else {
-            my $page_url = "$module.html";
-            $page_url =~ s{::}{/}g;
-
-            push @pages, Statocles::Page::Plain->new(
-                path => join( '/', $page_url ),
-                layout => $self->site->theme->template( site => 'layout.html' ),
-                template => $self->site->theme->template( perldoc => 'pod.html' ),
-                content => "$dom",
-                app => $self,
-            );
-
+            push @pages, Statocles::Page::Plain->new( %page_args );
         }
 
         # Add the source as a text file
-        my $source_url = "$module.src.html";
-        $source_url =~ s{::}{/}g;
         push @pages, Statocles::Page::Plain->new(
-            path => $source_url,
+            path => $source_path,
             layout => $self->site->theme->template( site => 'layout.html' ),
             template => $self->site->theme->template( perldoc => 'source.html' ),
             content => Path::Tiny->new( $path )->slurp,
             app => $self,
+            data => {
+                doc_path => $self->url( $page_args{path} ),
+                crumbtrail => \@crumbtrail,
+            },
         );
 
     }
@@ -156,6 +174,17 @@ sub pages {
     return @pages;
 }
 
+sub _module_href {
+    my ( $self, $module ) = @_;
+    if ( $module eq $self->index_module ) {
+        return join '/', 'index.html';
+    }
+
+    my $page_url = "$module.html";
+    $page_url =~ s{::}{/}g;
+    return $page_url;
+}
+
 
 sub _weave_module {
     my ( $self, $path ) = @_;
@@ -247,7 +276,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
