@@ -1,6 +1,6 @@
 package Statocles::App::Static;
 # ABSTRACT: Manage static files like CSS, JS, images, and other untemplated content
-$Statocles::App::Static::VERSION = '0.045';
+$Statocles::App::Static::VERSION = '0.046';
 use Statocles::Base 'Class';
 use Statocles::Page::File;
 with 'Statocles::App';
@@ -30,7 +30,7 @@ sub pages {
 
         push @pages, Statocles::Page::File->new(
             path => $path,
-            fh => $self->store->open_file( $path ),
+            file_path => $self->store->path->child( $path ),
         );
     }
 
@@ -49,7 +49,7 @@ Statocles::App::Static - Manage static files like CSS, JS, images, and other unt
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
