@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.045';
+$Statocles::Command::VERSION = '0.046';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -426,9 +426,14 @@ sub bundle_theme {
 
             my $asset = $self->static->file( $path );
             if ( !$asset ) {
-                # Check for index.html
-                $path = Mojo::Path->new( $c->stash->{path} . "/index.html" );
-                $asset = $self->static->file( $path );
+                if ( $path =~ m{/$} ) {
+                    # Check for index.html
+                    $path = Mojo::Path->new( $c->stash->{path} . "/index.html" );
+                    $asset = $self->static->file( $path );
+                }
+                elsif ( $self->site->build_store->path->child( $path )->is_dir ) {
+                    return $c->redirect_to( "/$path/" );
+                }
             }
 
             if ( !$asset ) {
@@ -466,7 +471,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
