@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.045';
+$Statocles::Document::VERSION = '0.046';
 use Statocles::Base 'Class';
 
 
@@ -57,6 +57,28 @@ has date => (
     predicate => 'has_date',
 );
 
+
+has template => (
+    is => 'rw',
+    isa => Maybe[ArrayRef[Str]],
+    coerce => sub {
+        return $_[0] if ref $_[0];
+        return [ grep { $_ ne '' } split m{/}, $_[0] ];
+    },
+    predicate => 'has_template',
+);
+
+
+has layout => (
+    is => 'rw',
+    isa => Maybe[ArrayRef[Str]],
+    coerce => sub {
+        return $_[0] if ref $_[0];
+        return [ grep { $_ ne '' } split m{/}, $_[0] ];
+    },
+    predicate => 'has_layout',
+);
+
 1;
 
 __END__
@@ -69,7 +91,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
@@ -124,6 +146,18 @@ supported attributes. The most common attributes are:
 The date/time this document is for. For pages, this is the last modified date.
 For blog posts, this is the post's date.
 
+=head2 template
+
+A template override for this document. If set, the L<document
+page|Statocles::Page::Document> will use this instead of the template provided
+by the application.
+
+=head2 layout
+
+A layout template override for this document. If set, the L<document
+page|Statocles::Page::Document> will use this instead of the layout provided
+by the application.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
