@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::VERSION = '0.045';
+$Statocles::Page::VERSION = '0.046';
 use Statocles::Base 'Role';
 use Statocles::Template;
 
@@ -35,6 +35,13 @@ has date => (
 );
 
 
+has data => (
+    is => 'ro',
+    isa => HashRef,
+    default => sub { {} },
+);
+
+
 has _links => (
     is => 'ro',
     isa => LinkHash,
@@ -87,6 +94,7 @@ sub vars { }
 sub render {
     my ( $self, %args ) = @_;
     my %vars = (
+        %{ $self->data },
         %args,
         self => $self,
         app => $self->app,
@@ -122,7 +130,7 @@ Statocles::Page - Render documents into HTML
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
@@ -148,6 +156,10 @@ The absolute URL path to save this page to.
 
 The date of this page. Used for last updated date and blog post dates.
 
+=head2 data
+
+A hash of additional template variables for this page.
+
 =head2 links
 
 A hash of arrays of links to pages related to this page. Possible keys:
