@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.045';
+$Statocles::Page::Document::VERSION = '0.046';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -80,6 +80,24 @@ sub tags {
     return @{ $self->_tags };
 }
 
+
+around template => sub {
+    my ( $orig, $self, @args ) = @_;
+    if ( $self->document->has_template ) {
+        return $self->site->theme->template( @{ $self->document->template } );
+    }
+    return $self->$orig( @args );
+};
+
+
+around layout => sub {
+    my ( $orig, $self, @args ) = @_;
+    if ( $self->document->has_layout ) {
+        return $self->site->theme->template( @{ $self->document->layout } );
+    }
+    return $self->$orig( @args );
+};
+
 1;
 
 __END__
@@ -92,7 +110,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
@@ -144,6 +162,18 @@ sections.
 
 Get the list of tags for this page.
 
+=head2 template()
+
+The L<template|Statocles::Template> for this page. If the document has a template,
+it will be used. Otherwise, the L<template attribute|Statocles::Page/template> will
+be used.
+
+=head2 layout()
+
+The L<layout template|Statocles::Template> for this page. If the document has a layout,
+it will be used. Otherwise, the L<layout attribute|Statocles::Page/layout> will
+be used.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
