@@ -1,14 +1,20 @@
 package Statocles::Page::File;
 # ABSTRACT: A page wrapping a file (handle)
-$Statocles::Page::File::VERSION = '0.045';
+$Statocles::Page::File::VERSION = '0.046';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 
 
+has file_path => (
+    is => 'ro',
+    isa => Path,
+    coerce => Path->coercion,
+);
+
+
 has fh => (
     is => 'ro',
     isa => FileHandle,
-    required => 1,
 );
 
 
@@ -19,7 +25,7 @@ sub vars { die "Unimplemented" }
 
 sub render {
     my ( $self ) = @_;
-    return $self->fh;
+    return $self->file_path ? $self->file_path->openr_raw : $self->fh;
 }
 
 1;
@@ -34,12 +40,18 @@ Statocles::Page::File - A page wrapping a file (handle)
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
-    open my $fh, '<', '/path/to/file.txt';
+    # File path
+    my $page = Statocles::Page::File->new(
+        path => '/path/to/page.txt',
+        file_path => '/path/to/file.txt',
+    );
 
+    # Filehandle
+    open my $fh, '<', '/path/to/file.txt';
     my $page = Statocles::Page::File->new(
         path => '/path/to/page.txt',
         fh => $fh,
@@ -52,9 +64,13 @@ L<store|Statocles::Store> to another.
 
 =head1 ATTRIBUTES
 
+=head2 file_path
+
+The path to the file.
+
 =head2 fh
 
-The file handle containing the contents of the page. Required.
+The file handle containing the contents of the page.
 
 =head1 METHODS
 
