@@ -1,6 +1,6 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.045';
+$Statocles::Page::List::VERSION = '0.046';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( max );
@@ -57,7 +57,7 @@ sub paginate {
         my $next = $i != $#sets ? sprintf( $path_format, $i + 2 ) : '';
 
         # Remove index.html from link URLs
-        s{/index[.]html$}{} for ( $prev, $next );
+        s{/index[.]html$}{/} for ( $prev, $next );
 
         push @retval, $class->new(
             path => $path,
@@ -92,7 +92,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
