@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.045';
+$Statocles::Site::VERSION = '0.046';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -304,13 +304,13 @@ sub url {
                 : $self->base_url;
 
     # Remove index.html from the end of the path, since it's redundant
-    $path =~ s{/index[.]html$}{};
+    $path =~ s{/index[.]html$}{/};
 
     # Remove the / from both sides of the join so we don't double up
     $base =~ s{/$}{};
     $path =~ s{^/}{};
 
-    return join "/", $base, ( $path || !$base ? ( $path ) : () );
+    return join "/", $base, $path;
 }
 
 1;
@@ -325,7 +325,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
